@@ -1,7 +1,9 @@
 "show.mle.ghyp" <- function(object)
 {
-  if(!object@converged){
+  if(!object@converged && !is.na(object@n.iter)){
      cat("Warning: fitting procedure did not converge!\n\n")
+  }else if(!object@converged && is.na(object@n.iter)){
+     cat("Error: fitting procedure crashed! Use 'summary' to see the message!\n\n")  
   }
  
   callNextMethod()
